<?php

/* /home/hoteles9/public_html/hotelplazamagdalena/themes/hotels/layouts/hotel.htm */
class __TwigTemplate_c42782072988c64150ed1be625cd5e8e2bb53309d2a1006d3f172505c5cae4c5 extends Twig_Template
{
    public function __construct(Twig_Environment $env)
    {
        parent::__construct($env);

        $this->parent = false;

        $this->blocks = array(
        );
    }

    protected function doDisplay(array $context, array $blocks = array())
    {
        // line 1
        echo "<!DOCTYPE html>
<html lang=\"es\" ng-app=\"hotel\">
\t<head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=gb18030\">
\t\t
\t\t<meta http-equiv=\"X-UA-Compatible\" content=\"IE=edge\">
\t\t<meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">
\t\t<title>";
        // line 7
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["company"]) ? $context["company"] : null), "name", array()), "html", null, true);
        echo "</title>

\t\t<meta name=\"description\" content=\"The Best Hotel to REST YOUR HEAD - 2015 Travelers Choise in Copan Ruins\">
\t\t<meta property=\"og:title\" content=\"Yat B'alam Hotel\" />
\t\t<meta property=\"og:type\" content=\"website\" />
\t\t<meta property=\"og:image\" content=\"http://yatbalam.com/fb-share.jpg\" />
\t\t<meta property=\"og:description\" content=\"The Best Hotel to REST YOUR HEAD - 2015 Travelers Choise in Copan Ruins\" />
\t\t<meta name=\"description\" content=\"The Best Hotel to REST YOUR HEAD - 2015 Travelers Choise in Copan Ruins\" />
\t\t<meta name=\"keywords\" content=\"Hotel, Piscina, Copán, turismo, boutique, comodidad, cultura, tradición, belleza\" />
\t\t<meta name=\"author\" content=\"naticode\">
\t\t
\t\t";
        // line 18
        echo $this->env->getExtension('CMS')->assetsFunction('css');
        echo $this->env->getExtension('CMS')->displayBlock('styles');
        // line 19
        echo "\t\t<link href=\"";
        echo $this->env->getExtension('CMS')->themeFilter(array(0 => "assets/css/ui-kit.css", 1 => "assets/css/font-awesome.min.css", 2 => "assets/css/weather-icons.min.css", 3 => "assets/css/animate.min.css", 4 => "assets/css/bootstrap.min.css", 5 => "assets/css/lightbox.css", 6 => "assets/css/pickaday.css", 7 => "assets/css/sweetalert.css", 8 => "assets/css/reset.css", 9 => "assets/css/style.css"));
        // line 30
        echo "\" rel=\"stylesheet\">

\t\t<link href='https://api.tiles.mapbox.com/mapbox.js/v2.1.5/mapbox.css' rel='stylesheet' />

\t\t<style>
\t\t\t.primary-bg{ background-color: ";
        // line 35
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "main_color", array()), "html", null, true);
        echo " !important; }
\t\t\t.primary-color, a:hover{ color: ";
        // line 36
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "main_color", array()), "html", null, true);
        echo " !important; }
\t\t\t.alt-bg{ background-color: ";
        // line 37
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "alt_color", array()), "html", null, true);
        echo " !important; }
\t\t\t.alt-color{ color: ";
        // line 38
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "alt_color", array()), "html", null, true);
        echo " !important; }
\t\t\t.white-bg{ background-color: #fff !important; }
\t\t\t.white-color{ color: #fff !important; }

\t\t    .primary-bg.emergency_number::after{ background-color: ";
        // line 42
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "main_color", array()), "html", null, true);
        echo " !important; }
\t\t\t.primary-bg.emergency_number a:hover{ color: #fff !important; opacity: 0.6; }
\t\t\t.alt-bg.emergency_number::after{ background-color: ";
        // line 44
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "alt_color", array()), "html", null, true);
        echo " !important; }
\t\t\t.primary-bg.quote:after{ border-color: ";
        // line 45
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "main_color", array()), "html", null, true);
        echo " transparent }
\t\t\t.alt-bg.quote:after{ border-color: ";
        // line 46
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "alt_color", array()), "html", null, true);
        echo " transparent }

\t\t\t.btn.btn-primary{ background-color: ";
        // line 48
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "main_color", array()), "html", null, true);
        echo "; color: #ffffff !important; }
\t\t\t.btn.btn-primary:hover{ background-color: ";
        // line 49
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "main_color", array()), "html", null, true);
        echo "; color: #fff; opacity: 0.8 !important; }

\t\t\t.nav-tabs > li.active > a,
\t\t\t.nav-tabs > li.active > a:focus,
\t\t\t.nav-tabs > li.active > a:hover,
\t\t\t.nav-tabs > li.active > a > img,
\t\t\t.hotel_facilities_content .our_services > a { color: ";
        // line 55
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "alt_color", array()), "html", null, true);
        echo " }
\t\t\t
\t\t\t.single_room_wrapper .uk-overlay:hover .left_room_title a.btn{ background-color: ";
        // line 57
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "main_color", array()), "html", null, true);
        echo "; opacity: 0.7; color: #fff; }
\t\t\t
\t\t\ta:hover {background-color:";
        // line 59
        echo twig_escape_filter($this->env, $this->getAttribute((isset($context["theme"]) ? $context["theme"] : null), "main_color", array()), "html", null, true);
        echo "; color:#ffffff;}
\t\t</style>

\t\t<!-- FavIcon -->
\t\t<link rel=\"shortcut icon\" href=\"";
        // line 63
        echo $this->env->getExtension('CMS')->themeFilter("assets/favicon.ico");
        echo "\" type=\"image/x-icon\" /> 
\t\t<link rel=\"icon\" href=\"";
        // line 64
        echo $this->env->getExtension('CMS')->themeFilter("assets/favicon.ico");
        echo "\" type=\"image/x-icon\">

\t\t<!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
\t\t<!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
\t\t<!--[if lt IE 9]>
\t\t\t<script src=\"https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js\"></script>
\t\t\t<script src=\"https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js\"></script>
\t\t<![endif]-->
\t</head>
\t<body id=\"home_one\">
\t\t";
        // line 74
        echo $this->env->getExtension('CMS')->pageFunction();
        // line 75
        echo "\t\t
\t\t<script src='https://api.tiles.mapbox.com/mapbox.js/v2.1.5/mapbox.js'></script>
\t\t<script src=\"";
        // line 77
        echo $this->env->getExtension('CMS')->themeFilter(array(0 => "assets/js/jquery.min.js", 1 => "assets/js/pickaday.js", 2 => "assets/js/lightbox.min.js", 3 => "assets/js/bootstrap.min.js", 4 => "assets/js/sweetalert.min.js", 5 => "assets/js/site.js"));
        // line 84
        echo "\"></script>
\t\t";
        // line 85
        echo '<script src="'. Request::getBasePath()
                .'/modules/system/assets/js/framework.js"></script>'.PHP_EOL;
        echo '<script src="'. Request::getBasePath()
                    .'/modules/system/assets/js/framework.extras.js"></script>'.PHP_EOL;
        echo '<link href="'. Request::getBasePath()
                    .'/modules/system/assets/css/framework.extras.css" rel="stylesheet">'.PHP_EOL;
        // line 86
        echo "\t\t";
        echo $this->env->getExtension('CMS')->assetsFunction('js');
        echo $this->env->getExtension('CMS')->displayBlock('scripts');
        // line 87
        echo "
\t\t<!--Start of Zopim Live Chat Script-->
\t\t<script type=\"text/javascript\">
\t\t// window.\$zopim||(function(d,s){var z=\$zopim=function(c){z._.push(c)},\$=z.s=
\t\t// d.createElement(s),e=d.getElementsByTagName(s)[0];z.set=function(o){z.set.
\t\t// _.push(o)};z._=[];z.set._=[];\$.async=!0;\$.setAttribute(\"charset\",\"utf-8\");
\t\t// \$.src=\"//v2.zopim.com/?2xt5y62c35tJecMLmii20sOS8irdAP8n\";z.t=+new Date;\$.
\t\t// type=\"text/javascript\";e.parentNode.insertBefore(\$,e)})(document,\"script\");
\t\t</script>
\t\t<!--End of Zopim Live Chat Script-->
\t</body>
</html>";
    }

    public function getTemplateName()
    {
        return "/home/hoteles9/public_html/hotelplazamagdalena/themes/hotels/layouts/hotel.htm";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  160 => 87,  156 => 86,  149 => 85,  146 => 84,  144 => 77,  140 => 75,  138 => 74,  125 => 64,  121 => 63,  114 => 59,  109 => 57,  104 => 55,  95 => 49,  91 => 48,  86 => 46,  82 => 45,  78 => 44,  73 => 42,  66 => 38,  62 => 37,  58 => 36,  54 => 35,  47 => 30,  44 => 19,  41 => 18,  27 => 7,  19 => 1,);
    }
}
/* <!DOCTYPE html>*/
/* <html lang="es" ng-app="hotel">*/
/* 	<head><meta http-equiv="Content-Type" content="text/html; charset=gb18030">*/
/* 		*/
/* 		<meta http-equiv="X-UA-Compatible" content="IE=edge">*/
/* 		<meta name="viewport" content="width=device-width, initial-scale=1">*/
/* 		<title>{{ company.name }}</title>*/
/* */
/* 		<meta name="description" content="The Best Hotel to REST YOUR HEAD - 2015 Travelers Choise in Copan Ruins">*/
/* 		<meta property="og:title" content="Yat B'alam Hotel" />*/
/* 		<meta property="og:type" content="website" />*/
/* 		<meta property="og:image" content="http://yatbalam.com/fb-share.jpg" />*/
/* 		<meta property="og:description" content="The Best Hotel to REST YOUR HEAD - 2015 Travelers Choise in Copan Ruins" />*/
/* 		<meta name="description" content="The Best Hotel to REST YOUR HEAD - 2015 Travelers Choise in Copan Ruins" />*/
/* 		<meta name="keywords" content="Hotel, Piscina, Copán, turismo, boutique, comodidad, cultura, tradición, belleza" />*/
/* 		<meta name="author" content="naticode">*/
/* 		*/
/* 		{% styles %}*/
/* 		<link href="{{ [*/
/* 			'assets/css/ui-kit.css',*/
/* 			'assets/css/font-awesome.min.css',*/
/* 			'assets/css/weather-icons.min.css',*/
/* 			'assets/css/animate.min.css',*/
/* 			'assets/css/bootstrap.min.css',*/
/* 			'assets/css/lightbox.css',*/
/* 			'assets/css/pickaday.css',*/
/* 			'assets/css/sweetalert.css',*/
/* 			'assets/css/reset.css',*/
/* 			'assets/css/style.css',*/
/* 		]|theme }}" rel="stylesheet">*/
/* */
/* 		<link href='https://api.tiles.mapbox.com/mapbox.js/v2.1.5/mapbox.css' rel='stylesheet' />*/
/* */
/* 		<style>*/
/* 			.primary-bg{ background-color: {{ theme.main_color }} !important; }*/
/* 			.primary-color, a:hover{ color: {{ theme.main_color }} !important; }*/
/* 			.alt-bg{ background-color: {{ theme.alt_color }} !important; }*/
/* 			.alt-color{ color: {{ theme.alt_color }} !important; }*/
/* 			.white-bg{ background-color: #fff !important; }*/
/* 			.white-color{ color: #fff !important; }*/
/* */
/* 		    .primary-bg.emergency_number::after{ background-color: {{ theme.main_color }} !important; }*/
/* 			.primary-bg.emergency_number a:hover{ color: #fff !important; opacity: 0.6; }*/
/* 			.alt-bg.emergency_number::after{ background-color: {{ theme.alt_color }} !important; }*/
/* 			.primary-bg.quote:after{ border-color: {{ theme.main_color }} transparent }*/
/* 			.alt-bg.quote:after{ border-color: {{ theme.alt_color }} transparent }*/
/* */
/* 			.btn.btn-primary{ background-color: {{ theme.main_color }}; color: #ffffff !important; }*/
/* 			.btn.btn-primary:hover{ background-color: {{ theme.main_color }}; color: #fff; opacity: 0.8 !important; }*/
/* */
/* 			.nav-tabs > li.active > a,*/
/* 			.nav-tabs > li.active > a:focus,*/
/* 			.nav-tabs > li.active > a:hover,*/
/* 			.nav-tabs > li.active > a > img,*/
/* 			.hotel_facilities_content .our_services > a { color: {{ theme.alt_color }} }*/
/* 			*/
/* 			.single_room_wrapper .uk-overlay:hover .left_room_title a.btn{ background-color: {{ theme.main_color }}; opacity: 0.7; color: #fff; }*/
/* 			*/
/* 			a:hover {background-color:{{theme.main_color}}; color:#ffffff;}*/
/* 		</style>*/
/* */
/* 		<!-- FavIcon -->*/
/* 		<link rel="shortcut icon" href="{{ 'assets/favicon.ico'|theme }}" type="image/x-icon" /> */
/* 		<link rel="icon" href="{{ 'assets/favicon.ico'|theme }}" type="image/x-icon">*/
/* */
/* 		<!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->*/
/* 		<!-- WARNING: Respond.js doesn't work if you view the page via file:// -->*/
/* 		<!--[if lt IE 9]>*/
/* 			<script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>*/
/* 			<script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>*/
/* 		<![endif]-->*/
/* 	</head>*/
/* 	<body id="home_one">*/
/* 		{% page %}*/
/* 		*/
/* 		<script src='https://api.tiles.mapbox.com/mapbox.js/v2.1.5/mapbox.js'></script>*/
/* 		<script src="{{ [*/
/* 			'assets/js/jquery.min.js',*/
/* 			'assets/js/pickaday.js',*/
/* 			'assets/js/lightbox.min.js',*/
/* 			'assets/js/bootstrap.min.js',*/
/* 			'assets/js/sweetalert.min.js',*/
/* 			'assets/js/site.js'*/
/* 		]|theme }}"></script>*/
/* 		{% framework extras %}*/
/* 		{% scripts %}*/
/* */
/* 		<!--Start of Zopim Live Chat Script-->*/
/* 		<script type="text/javascript">*/
/* 		// window.$zopim||(function(d,s){var z=$zopim=function(c){z._.push(c)},$=z.s=*/
/* 		// d.createElement(s),e=d.getElementsByTagName(s)[0];z.set=function(o){z.set.*/
/* 		// _.push(o)};z._=[];z.set._=[];$.async=!0;$.setAttribute("charset","utf-8");*/
/* 		// $.src="//v2.zopim.com/?2xt5y62c35tJecMLmii20sOS8irdAP8n";z.t=+new Date;$.*/
/* 		// type="text/javascript";e.parentNode.insertBefore($,e)})(document,"script");*/
/* 		</script>*/
/* 		<!--End of Zopim Live Chat Script-->*/
/* 	</body>*/
/* </html>*/
